@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.12 2001/02/15 12:38:15 jirka Exp $ */
+/* $Id: dict.c,v 1.16 2002/04/04 03:38:26 kevinv Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -16,6 +16,8 @@
 #  include <config.h>
 #endif
 
+#include <sys/types.h>
+#include <sys/socket.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -75,7 +77,7 @@ void dict_res_destroy (dict_res_t *res)
 static int dict_write (dict_context_t *context, GString *str) 
 {
     int res, amt;
-    
+  
     res = g_io_channel_write(context->channel, str->str, str->len, &amt);
     
     if (res != G_IO_ERROR_NONE)
@@ -96,7 +98,7 @@ dict_command_done (dict_command_t *command)
 
     command->context = NULL;
     command->state = S_DONE;
-    
+  
     if (context) {
         context->command = NULL;
         if (command->temp_context) {
@@ -159,7 +161,7 @@ static char *dict_read_line (dict_context_t *context) {
     char *start_ptr, *end_ptr;
     
     if (!context->channel) return NULL;
-    
+   
     while (1) {
         end_ptr = strchr (context->read_ptr, '\r');
         
@@ -194,7 +196,7 @@ static void data_notify_match (dict_context_t *context, char *line)
     dict_command_t *command;
     
     command = context->command;
-    
+   
     switch (command->state) {
     case S_GROUND:      /* Uh oh... problem */
     case S_DONE:
@@ -244,7 +246,7 @@ static void data_notify_match (dict_context_t *context, char *line)
         break;
         
     case S_DATA:
-        if (!strcmp (line, ".\n")) {
+        if (line != NULL && strcmp (line, ".\n") == 0) {
             command->state = S_STATUS;
         }
         else {
@@ -287,7 +289,7 @@ static void data_notify_define (dict_context_t *context, char *line)
     dict_command_t *command;
     
     command = context->command;
-    
+   
     switch (command->state) {
     case S_GROUND:      /* Uh oh... problem */
     case S_DONE:
@@ -384,7 +386,7 @@ static void data_notify_show_db (dict_context_t *context, char *line)
     dict_command_t *command;
     
     command = context->command;
-    
+   
     switch (command->state) {
     case S_GROUND:      /* Uh oh... problem */
     case S_DONE:
@@ -466,7 +468,7 @@ static void data_notify_show_strat (dict_context_t *context,
     dict_command_t *command;
     
     command = context->command;
-    
+   
     switch (command->state) {
     case S_GROUND:      /* Uh oh... problem */
     case S_DONE:
@@ -544,7 +546,7 @@ static void data_notify_connect (dict_context_t *context, char *line)
     dict_command_t *command;
     
     command = context->command;
-    
+   
     switch (command->state) {
     case S_GROUND:      /* Uh oh... problem */
     case S_DATA:
@@ -579,7 +581,7 @@ static void data_notify_quit (dict_context_t *context, char *line)
     dict_command_t *command;
     
     command = context->command;
-    
+   
     switch (command->state) {
     case S_GROUND:      /* Uh oh... problem */
     case S_DATA:
@@ -616,7 +618,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
      * even after connection was closed */
     if (context->channel == NULL)
 	    return FALSE;
-    
+  
     if (cond == G_IO_IN) {
         context->read_cycle_done = FALSE;
         
@@ -628,7 +630,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
 	    g_free (line);
         }
     }
-    else if (cond == G_IO_ERR) {
+    else if (cond & G_IO_ERR) {
         if (context->command->error_notify_cb)
 	    context->command->error_notify_cb (context->command, 
 					       DICT_SOCKET_ERROR,
@@ -637,6 +639,21 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
         dict_disconnect (context);
 	return FALSE;
     }
+    else {
+        GtkWidget *dialog;
+        /* Strange error here */
+        
+        dict_disconnect (context);
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         GTK_MESSAGE_ERROR,
+                                         GTK_BUTTONS_CLOSE,
+                                         _("A serious error occured. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
+        g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
+                                  G_CALLBACK (gtk_widget_destroy),
+                                  GTK_OBJECT (dialog));
+	gtk_widget_show_all (dialog);
+	return FALSE;
+    }
     
     return TRUE;
 }
@@ -732,7 +749,7 @@ int dict_connect (dict_context_t *context)
     if (fcntl (sock_fd, F_SETFL, old_flags | O_NONBLOCK) == -1)
 	return -1;
     
-    if (connect(sock_fd, &context->sockaddr, sizeof(context->sockaddr)) != 0
+    if (connect(sock_fd, (struct sockaddr*)&context->sockaddr, sizeof(context->sockaddr)) != 0
 	&& errno != EINPROGRESS)
 	return -1;
     
@@ -1003,7 +1020,7 @@ int dict_command_invoke (dict_command_t *command,
         dict_disconnect (context);
         return 0;
     }
-    
+   
     /* Otherwise, the context is free, so just assign it as the context we
      * are going to use
      */
@@ -1012,12 +1029,12 @@ int dict_command_invoke (dict_command_t *command,
         command->context = context;
     }
     
-    
+   
     /* If this context is not already connected to the server, initiate
      * a command to connect it and set the given command to be triggered
      * when the connection is established
      */
-    
+   
     if (!command->context->channel && command->cmd != C_CONNECT) {
         sec_cmd = dict_connect_command_new ();
         sec_cmd->trigger_cmd = command;
@@ -1027,7 +1044,7 @@ int dict_command_invoke (dict_command_t *command,
         sec_cmd->user_data = command->user_data;
         return dict_command_invoke (sec_cmd, command->context);
     }
-    
+  
     /* If this is a connect command, then go ahead and connect to the server */
     
     else if (command->cmd == C_CONNECT) {
@@ -1043,7 +1060,7 @@ int dict_command_invoke (dict_command_t *command,
         command->state = S_STATUS;
         if (dict_write (command->context, command->cmd_string)) return -1;
     }
-    
+  
     return 0;
 }
 
