@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.4 2000/02/04 23:34:50 spapadim Exp $ */
+/* $Id: gdict-about.c,v 1.8 2002/02/28 23:01:54 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -32,14 +32,22 @@ static GtkWidget *gdict_about_new (void)
         "Bradford Hovinen <hovinen@udel.edu>",
         NULL
     };
+    gchar *documenters[] = {
+	    NULL
+    };
+    /* Translator credits */
+    gchar *translator_credits = _("translator_credits");
     GtkWidget *about;
     
-    about = gnome_about_new ("GDict", VERSION,
+    about = gnome_about_new ("GNOME Dictionary", VERSION,
                              "Copyright 1999 by Mike Hughes",
-                             authors,
-                             _("Client for MIT dictionary server.\nWeb: http://gdict.dhs.org/, http://www.psilord.com/code/"),
+                             _("Client for MIT dictionary server.\n"
+			    "Web: http://gdict.dhs.org/, "
+			    "http://www.psilord.com/code/"),
+			     (const char **)authors,
+			     (const char **)documenters,
+			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
                              NULL);
-    gtk_window_set_modal (GTK_WINDOW (about), TRUE);
     return about;
 }
 
