@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.10 2001/12/14 00:38:59 kevinv Exp $ */
+/* $Id: gdict-speller.c,v 1.12 2002/03/21 03:33:47 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -42,6 +42,8 @@ enum {
     LAST_SIGNAL
 };
 
+GtkWidget *ss_label;
+
 static gint gdict_speller_signals[LAST_SIGNAL] = { 0, 0, 0 };
 
 static GnomeDialogClass *parent_class;
@@ -110,6 +112,8 @@ gdict_speller_get_type (void) {
 static void 
 gdict_speller_init (GDictSpeller *speller) {
     GtkWidget *label, *button, *scrolled_win;
+    GtkWidget *sep;
+    GtkWidget *hbox;
     GtkListStore *model;
     GtkTreeViewColumn *column;
     GtkTreeSelection *selection;
@@ -120,34 +124,68 @@ gdict_speller_init (GDictSpeller *speller) {
     speller->spell_cmd = NULL;
     speller->strat = gdict_pref.dfl_strat;
     
-    speller->table = GTK_TABLE (gtk_table_new (2, 3, FALSE));
-    gtk_table_set_row_spacings (speller->table, 5);
-    gtk_table_set_col_spacings (speller->table, 5);
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, FALSE, 0);
     
-    button = gtk_button_new_with_mnemonic (_("_Spell"));
-    gtk_table_attach_defaults (speller->table, button, 0, 1, 0, 1);
-    g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (spell_button_pressed),
-    		      speller);
+    label = gtk_label_new_with_mnemonic (_("_Word : "));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     
     speller->word_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_table_attach_defaults (speller->table, 
-		               GTK_WIDGET (speller->word_entry), 1, 2, 0, 1);
+    gtk_label_set_mnemonic_widget ( GTK_LABEL(label), GTK_WIDGET(speller->word_entry));
+
+    gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (speller->word_entry), TRUE, TRUE, 0);
     g_signal_connect (G_OBJECT (speller->word_entry), "activate",
     	  	      G_CALLBACK (spell_entry_cb), speller);
+
+    if ( gail_loaded )
+
+    {
+        add_atk_namedesc(label, _("Word"), _("Word"));
+        add_atk_namedesc(GTK_WIDGET(speller->word_entry), _("Word Entry"), _("Enter a word to know the spelling"));
+        add_atk_relation(GTK_WIDGET(speller->word_entry), label, ATK_RELATION_LABELLED_BY);
+
+    }
+ 
+    label = gtk_label_new_with_mnemonic (_("_Spell"));
+    gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 1);
     
-    label = gtk_label_new (_("Search Strategy:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (speller->table, label, 0, 1, 1, 2);
+    button = gtk_button_new ();
+    gtk_container_add (GTK_CONTAINER (button), label);
+    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+    g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (spell_button_pressed),
+    		      speller);
+    if( gail_loaded )
+        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Click to do the spell check"));
+    speller->hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_container_set_border_width (GTK_CONTAINER (speller->hbox), GNOME_PAD);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), speller->hbox, 
+    			FALSE, FALSE, 0);
+    
+    ss_label = gtk_label_new_with_mnemonic (_("Search S_trategy:"));
+    gtk_label_set_justify (GTK_LABEL (ss_label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (ss_label), 1, 0.5);
+    gtk_box_pack_start (GTK_BOX (speller->hbox), ss_label, FALSE, FALSE, 0);
+        
+    hbox = gtk_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, 
+    			FALSE, GNOME_PAD_SMALL);
+    
+    hbox = gtk_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, FALSE, 0);
+    
+    label = gtk_label_new (_("Search Results"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    
+    sep = gtk_hseparator_new ();
+    gtk_box_pack_start (GTK_BOX (hbox), sep, TRUE, TRUE, GNOME_PAD_SMALL);
     
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                     GTK_POLICY_NEVER,
                                     GTK_POLICY_AUTOMATIC);
     gtk_widget_set_usize (scrolled_win, 400, 250);
-    
-    gtk_table_attach (speller->table, scrolled_win, 0, 2, 2, 3, 
-                      GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 5);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), scrolled_win, 
+    			TRUE, TRUE, GNOME_PAD);
     
     model = gtk_list_store_new (1, G_TYPE_STRING);
     
@@ -166,24 +204,24 @@ gdict_speller_init (GDictSpeller *speller) {
     						       NULL);
     gtk_tree_view_column_set_sort_column_id (column, 0);
     
-    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-                                          0,GTK_SORT_ASCENDING); 
+    /*gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
+                                          0,GTK_SORT_ASCENDING); */
                                           
     gtk_tree_view_append_column (GTK_TREE_VIEW (speller->word_list), column);
     gtk_container_add (GTK_CONTAINER (scrolled_win), speller->word_list);
 
     gtk_dialog_add_buttons (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-    		                                  _("_Look Up"), 100,
-    		                                  NULL);
+                                                  _("_Look Up Word"), 100,
+                                                  NULL);
+
     g_signal_connect (G_OBJECT (speller->word_list), "row_activated",
-    		      G_CALLBACK (row_activated_cb), speller);	                                  
+    		      G_CALLBACK (row_activated_cb), speller);
+    		      
     g_signal_connect (G_OBJECT (speller), "response", G_CALLBACK (spell_response_cb),
     		      speller);
     gtk_window_set_title (GTK_WINDOW (speller), _("Spell checker"));
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox),
-                        GTK_WIDGET (speller->table), 5, TRUE, TRUE);
-                         
-    gtk_widget_show_all (GTK_WIDGET (speller->table));
+                           
+    gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (speller)->vbox));
 }
 
 /* gdict_speller_class_init
@@ -389,7 +427,7 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
     if (speller->strat_sel) {
         gtk_option_menu_remove_menu (speller->strat_sel);
         gtk_widget_destroy (GTK_WIDGET (speller->strat_sel));
-        gtk_widget_show_all (GTK_WIDGET (speller->table));
+        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
         speller->strat_sel = NULL;
     }
     
@@ -412,8 +450,8 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (error_label));
-        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
-        gtk_widget_show_all (GTK_WIDGET (speller->table));
+        gtk_box_pack_start (GTK_BOX (speller->hbox), alignment, TRUE, TRUE, 0);
+        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
     }
 }
 
@@ -491,12 +529,17 @@ speller_set_strat_cb (GtkWidget *widget, gpointer data) {
 static void
 speller_add_strat (GDictSpeller *speller, gchar *strat, gchar *desc) {
     GtkWidget *menu_item;
+    GtkWidget *label;
     
-    menu_item = gtk_menu_item_new_with_label (desc);
+    label = gtk_label_new (desc);
+    gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+    
+    menu_item = gtk_menu_item_new ();
     gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
                         GTK_SIGNAL_FUNC (speller_set_strat_cb), speller);
     gtk_object_set_data (GTK_OBJECT (menu_item), "strat_name", strat);
-    gtk_widget_show (menu_item);
+    gtk_container_add (GTK_CONTAINER (menu_item), label);
+    gtk_widget_show_all (menu_item);
     gtk_menu_append (speller->strat_list, menu_item);
     
     if (!strcmp (speller->strat, strat))
@@ -578,15 +621,25 @@ spell_strat_status_cb (dict_command_t *command, DictStatusCode code,
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (speller->strat_sel));
-        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
-        gtk_widget_show_all (GTK_WIDGET (speller->table));
+        gtk_box_pack_start (GTK_BOX (speller->hbox), alignment, TRUE, TRUE, 0);
+        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
+
+        gtk_label_set_mnemonic_widget (GTK_LABEL (ss_label), GTK_WIDGET (speller->strat_sel));        
+
+        if ( gail_loaded )
+        {
+            add_atk_namedesc(ss_label, _("Search Strategy"), _("Search Strategy"));
+            add_atk_relation(ss_label, GTK_WIDGET (speller->strat_sel), ATK_RELATION_LABEL_FOR);
+            add_atk_relation( GTK_WIDGET (speller->strat_sel), ss_label, ATK_RELATION_LABELLED_BY);
+        }
+ 
     }
 }
 
 static void
 spell_response_cb (GtkDialog *dialog, gint id, gpointer data) {
 	GDictSpeller *speller;
-	
+        
 	g_return_if_fail (data);
 	speller = GDICT_SPELLER (data);
 	
