@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.26 2002/01/09 02:02:32 kevinv Exp $ */
+/* $Id: main.c,v 1.29 2002/03/16 21:00:04 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -51,6 +51,11 @@ static gint save_yourself_cb (GnomeClient       *client,
     return TRUE;
 }
 
+static gint client_die_cb (GnomeClient *client, gpointer client_data)
+{
+	gtk_main_quit ();
+}
+
 int main (int argc, char *argv[])
 {
     gint i;
@@ -60,7 +65,7 @@ int main (int argc, char *argv[])
     
 
     static struct poptOption args[] = {
-        {"noapplet", 'a', POPT_ARG_NONE, 0, 0, "Startup without applet support", NULL},
+        {"noapplet", 'a', POPT_ARG_NONE, 0, 0, "Legacy support - no longer is necessary", NULL},
         {NULL, 0, 0, NULL, 0, NULL, NULL}
     };
 
@@ -68,28 +73,22 @@ int main (int argc, char *argv[])
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
-    gnome_init_with_popt_table ("gdict", VERSION, argc, argv,
+    gnome_init_with_popt_table ("gnome-dictionary", VERSION, argc, argv,
                                     args, 0, NULL);
 
-    if ((client = gnome_master_client()) != NULL)
-            gtk_signal_connect (GTK_OBJECT(client), "save_yourself",
-                                GTK_SIGNAL_FUNC(save_yourself_cb),
-				(gpointer) argv[0]);
+    if ((client = gnome_master_client()) != NULL) {
+            g_signal_connect (client, "save_yourself",
+                              G_CALLBACK (save_yourself_cb),
+                              (gpointer) argv[0]);
+            g_signal_connect (client, "die", G_CALLBACK (client_die_cb), NULL);
+    }
     
     
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
     gdict_app_create (FALSE);
     gdict_pref_load ();
-    if (gdict_init_context () < 0)
-      {
-            GtkWidget *dialog;
-            
-            dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  	     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  	     "%s", _("The server could not be contacted. \nIf you are not connected to the internet please do so."), NULL); 
-	    gtk_dialog_run (GTK_DIALOG (dialog));
-	    gtk_widget_destroy (dialog);
-      }
+
+    gdict_init_context ();
     defbox->context = context;
 
     for (i = 1;  i < argc;  i++)
