@@ -21,6 +21,7 @@
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h> 
+#include <gdk/gdkkeysyms.h>
 
 #include <string.h>
 #include <unistd.h>
@@ -60,18 +61,16 @@ enum {
 };
 
 const FindOptionTemplate templates[] = {
-	{ FIND_OPTION_TEXT, "-iname '%s'", N_("File name is") },
-	{ FIND_OPTION_TEXT, "'!' -iname '%s'", N_("File name is not") }, 
+	{ FIND_OPTION_TEXT, "-name '%s'", N_("File name is") },
+	{ FIND_OPTION_TEXT, "'!' -name '%s'", N_("File name is not") }, 
 	{ FIND_OPTION_BOOL, "-mount", N_("Don't search mounted filesystems") },
 	{ FIND_OPTION_BOOL, "-follow", N_("Follow symbolic links") },	
 	{ FIND_OPTION_BOOL, "-depth", N_("Process directory contents depth first") },
-	{ FIND_OPTION_BOOL, "-maxdepth 1", N_("Don't search subdirectories") },
 	{ FIND_OPTION_TEXT, "-user '%s'", N_("Owned by user") },
 	{ FIND_OPTION_TEXT, "-group '%s'", N_("Owned by group") },
-	{ FIND_OPTION_BOOL, "-nouser -o -nogroup", N_("Invalid user or group") },
+	{ FIND_OPTION_BOOL, "\\( -nouser -o -nogroup \\)", N_("Invalid user or group") },
 	{ FIND_OPTION_TIME, "-mtime '%s'", N_("Last time modified") },
-	{ FIND_OPTION_BOOL, "-empty", N_("File is empty") },
-	{ FIND_OPTION_TEXT, "-regex '%s'", N_("Matches regular expression") },
+	{ FIND_OPTION_BOOL, "-size 0c \\( -type f -o -type d \\)", N_("File is empty") },
 	{ FIND_OPTION_END, NULL,NULL}
 };
 
@@ -81,6 +80,7 @@ const static char defoptions[] = "'!' -type d";
 /*char defoptions[] = "-mindepth 0";*/
 
 GList *criteria_find = NULL;
+gboolean  gail_loaded = FALSE;
 
 static GtkWidget *find_box = NULL;
 
@@ -128,122 +128,6 @@ static char *filename = NULL;
 
 static GtkWidget *save_widget = NULL;
 
-/* memrchr is gnu specific */
-static const void *
-my_memrchr (const void *mem, int c, size_t n)
-{
-	const char *s = mem;
-	while (n >= 0) {
-		if (s[n] == c)
-			return &s[n];
-		n--;
-	}
-	return NULL;
-}
-
-static gchar *
-get_file_base_name (char const *file)
-{
-  	/* based on code from basename.c of sh-utils */
-  	char const *base = file;
-  	int all_slashes = 1;
-  	char const *p;
-
-  	for (p = file; *p; p++)
-    	{
-      		if (ISSLASH (*p))
-			base = p + 1;
-      		else
-			all_slashes = 0;
-    	}
-
-  	/* If NAME is all slashes, arrange to return `/'.  */
-  	if (*base == '\0' && ISSLASH (*file) && all_slashes)
-    		--base;
-
-  	/* Make sure the last byte is not a slash.  */
-  	if (!(all_slashes || !ISSLASH (*(p - 1)))) 
-  		return (char *) file;
-  	else
-  		return (char *) base;
-}
-
-static size_t
-dir_name_r (const char *path, const char **result)
-{
-  	const char *slash;
-  	int length;	/* Length of result, not including NULL. */
-
-  	slash = strrchr (path, '/');
-  	if (BACKSLASH_IS_PATH_SEPARATOR)
-    	{
-      		char *b = strrchr (path, '\\');
-      		if (b && slash < b)
-			slash = b;
-    	}
-
-  	if (slash && slash[1] == 0)
-    	{
-      		while (path < slash && ISSLASH (slash[-1]))
-		{
-	  		--slash;
-		}
-
-      		if (path < slash)
-		{
-	  	slash = my_memrchr (path, '/', slash - path);
-	  		if (BACKSLASH_IS_PATH_SEPARATOR)
-	    		{
-	      			const char *b = my_memrchr (path, '\\', slash - path);
-	      			if (b && slash < b)
-				slash = b;
-	    		}
-		}
-    	}
-
-  	if (slash == 0)
-    	{
-      		path = ".";
-      		length = 1;
-    	}
-  	else
-    	{
-      		if (BACKSLASH_IS_PATH_SEPARATOR)
-		{
-	  		const char *lim = ((path[0] >= 'A' && path[0] <= 'z'
-					      && path[1] == ':')
-			 		      ? path + 2 : path);
-
-	  		while (slash > lim && ISSLASH (*slash))
-	    		--slash;
-		}
-      		else
-		{
-	  		while (slash > path && ISSLASH (*slash))
-	    		--slash;
-		}
-
-      		length = slash - path + 1;
-    	}
-
-  	*result = path;
-  	return length;
-}
-
-static gchar *
-get_file_dir_name (const char *file)
-{
-	/* based on code from dirname.c of sh-utils */
-  	const char *result;
-  	size_t length = dir_name_r (file, &result);
-	char *newpath = (char *) malloc (length + 1);
-	if (newpath == 0)
-		return 0;
-	strncpy (newpath, result, length);
-  	newpath[length] = 0;
-  	return newpath;
-} 
-
 static int
 count_char (const char *s, char p)
 {
@@ -338,6 +222,7 @@ make_locate_cmd(void)
 {
 	GString *cmdbuf;
 	gchar *locate_string;
+	gchar *locate_command;
 	
 	locate_string = 
 		(gchar *)gtk_entry_get_text(GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(locate_entry))));
@@ -348,7 +233,15 @@ make_locate_cmd(void)
 	}
 
 	cmdbuf = g_string_new ("");
-	g_string_append_printf(cmdbuf, "locate '%s'", locate_string);
+	locate_command = g_find_program_in_path ("locate");
+	if (locate_command != NULL)
+	{
+		g_string_append_printf (cmdbuf, "%s '%s'", locate_command, locate_string);
+	} else {
+		g_string_append_printf (cmdbuf, "find \"/\" -name '%s' -mount", locate_string);
+	}
+	g_free (locate_string);
+	g_free (locate_command);
 	
 	return g_string_free (cmdbuf, FALSE);
 }
@@ -613,9 +506,9 @@ add_file_to_list_store(const gchar *file, GtkListStore *store, GtkTreeIter *iter
 	readable_size = gnome_vfs_format_file_size_for_display (vfs_file_info->size);
 	readable_date = get_readable_date (vfs_file_info->mtime);
 	date = get_basic_date (vfs_file_info->mtime);
-	utf8_base_name = g_locale_to_utf8 (get_file_base_name(file), -1, NULL, 
+	utf8_base_name = g_locale_to_utf8 (g_path_get_basename(file), -1, NULL, 
 					   NULL, NULL);
-	utf8_dir_name = g_locale_to_utf8 (get_file_dir_name(file), -1, NULL, 
+	utf8_dir_name = g_locale_to_utf8 (g_path_get_dirname(file), -1, NULL, 
 					  NULL, NULL);
 
 	gtk_list_store_append (GTK_LIST_STORE(store), iter); 
@@ -641,6 +534,63 @@ add_file_to_list_store(const gchar *file, GtkListStore *store, GtkTreeIter *iter
 	g_free (date);
 }
 
+
+/*
+ * add_atk_namedesc
+ * @widget    : The Gtk Widget for which @name and @desc are added.
+ * @name      : Accessible Name
+ * @desc      : Accessible Description
+ * Description: This function adds accessible name and description to a
+ *              Gtk widget.
+ */
+
+void
+add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc)
+{
+	AtkObject *atk_widget;
+
+	g_return_if_fail (GTK_IS_WIDGET(widget));
+
+	atk_widget = gtk_widget_get_accessible(widget);
+
+	if (name != NULL)
+		atk_object_set_name(atk_widget, name);
+	if (desc !=NULL)
+		atk_object_set_description(atk_widget, desc);
+}
+
+
+/*
+ * add_atk_relation
+ * @obj1      : The first widget in the relation @rel_type
+ * @obj2      : The second widget in the relation @rel_type.
+ * @rel_type  : Relation type which relates @obj1 and @obj2
+ * Description: This function establishes Atk Relation between two given
+ *              objects.
+ */
+
+void
+add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType rel_type)
+{
+	AtkObject *atk_obj1, *atk_obj2;
+	AtkRelationSet *relation_set;
+	AtkRelation *relation;
+	
+	g_return_if_fail (GTK_IS_WIDGET(obj1));
+	g_return_if_fail (GTK_IS_WIDGET(obj2));
+	
+	atk_obj1 = gtk_widget_get_accessible(obj1);
+			
+	atk_obj2 = gtk_widget_get_accessible(obj2);
+	
+	relation_set = atk_object_ref_relation_set (atk_obj1);
+	relation = atk_relation_new(&atk_obj2, 1, rel_type);
+	atk_relation_set_add(relation_set, relation);
+	g_object_unref(G_OBJECT (relation));
+	
+}
+
+
 static void
 really_run_command(char *cmd, char sepchar, RunLevel *running, GtkWidget *tree, GtkListStore *store, GtkTreeIter *iter)
 {
@@ -868,7 +818,7 @@ run_cmd_dialog(GtkWidget *wid, gpointer data)
 	char *cmd;
 	char *start_dir;
 	GtkWidget *dlg;
-	GtkWidget *w;
+	GtkWidget *w, *label;
 
 	if(start_dir_e) {
 		start_dir = gnome_file_entry_get_full_path(GNOME_FILE_ENTRY(start_dir_e), TRUE);
@@ -908,10 +858,10 @@ run_cmd_dialog(GtkWidget *wid, gpointer data)
 		      
 	gtk_dialog_set_default_response (GTK_DIALOG(dlg), GTK_RESPONSE_CLOSE); 
 
-	w = gtk_label_new(_("This is the command line that can be used to "
+	label = gtk_label_new(_("This is the command line that can be used to "
 			    "execute this search from the console."
 			    "\n\nCommand:"));
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), w, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), label, TRUE, TRUE, 0);
 	
 	w = gtk_entry_new();
 	gtk_editable_set_editable(GTK_EDITABLE(w), FALSE);
@@ -922,6 +872,13 @@ run_cmd_dialog(GtkWidget *wid, gpointer data)
                              	  "response", 
                              	  G_CALLBACK (gtk_widget_destroy),
                                   GTK_OBJECT (dlg));
+	if (gail_loaded)
+	{
+		add_atk_namedesc (GTK_WIDGET(label), _("Command"), NULL);
+		add_atk_namedesc (GTK_WIDGET(w), _("Command Line Entry"), _("Use this command line to execute the search from console"));
+		add_atk_relation (w, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
+		add_atk_relation (GTK_WIDGET(label), w, ATK_RELATION_LABEL_FOR);
+	}
 
 	gtk_widget_show_all(dlg); 
 	
@@ -985,25 +942,6 @@ launch_nautilus (char *file)
 	g_free(argv);
 }
 
-static gchar*
-get_file_full_path_name(gchar *utf8_path, gchar *utf8_name)
-{
-	static gchar *full_name;
-	gchar *path, *name;
-	
-	name = g_locale_from_utf8 (utf8_name, -1, NULL, NULL, NULL);
-	path = g_locale_from_utf8 (utf8_path, -1, NULL, NULL, NULL); 
-
-	if (path[strlen(path) - 1] == '/')
-		full_name = g_strconcat (path, name, NULL);
-	else
-		full_name = g_strconcat (path, "/", name, NULL);
-
-	g_free(path);
-	g_free(name);
-	return full_name;
-}
-
 static gboolean
 launch_file (GtkWidget *w, GdkEventButton *event, gpointer data)
 {
@@ -1031,7 +969,7 @@ launch_file (GtkWidget *w, GdkEventButton *event, gpointer data)
 		gtk_tree_model_get(GTK_TREE_MODEL(store),&iter,COLUMN_NAME, &utf8_name,
 							       COLUMN_PATH, &utf8_path,
 								-1);
-		file = get_file_full_path_name (utf8_path, utf8_name);
+		file = g_build_filename (utf8_path, utf8_name, NULL);
 		
 		if (nautilus_is_running ()) {
 			launch_nautilus (file);
@@ -1151,13 +1089,24 @@ set_option_defaults(FindOption *opt)
 	}
 }
 
+/*
+ * This function starts advanced search when the user presses Enter/Return
+ */
+
+static void
+advanced_search_activate (GtkWidget *entry, gpointer data)
+{
+	GtkWidget **buttons = data;
+	run_command (buttons[1], buttons);
+}
+
 static GtkWidget *
 create_option_box(FindOption *opt, gboolean enabled)
 {
 	GtkWidget *hbox;
 	GtkWidget *option;
 	GtkWidget *frame;
-	GtkWidget *w;
+	GtkWidget *w, *label;
 
 	hbox = gtk_hbox_new(FALSE,5);
 
@@ -1174,12 +1123,22 @@ create_option_box(FindOption *opt, gboolean enabled)
 	case FIND_OPTION_NUMBER:
 	case FIND_OPTION_TIME:
 		option = gtk_hbox_new(FALSE,5);
-		w = gtk_label_new(_(templates[opt->templ].desc));
-		gtk_box_pack_start(GTK_BOX(option),w,FALSE,FALSE,0);
+		label = gtk_label_new(_(templates[opt->templ].desc));
+		gtk_box_pack_start(GTK_BOX(option),label,FALSE,FALSE,0);
 		w = gtk_entry_new();
 		g_signal_connect(G_OBJECT(w),"changed",
 				 G_CALLBACK(entry_changed),opt);
 		gtk_box_pack_start(GTK_BOX(option),w,TRUE,TRUE,0);
+
+		if (gail_loaded)
+		{
+			add_atk_namedesc (GTK_WIDGET(w), _("Search Rule Value Entry"), _("Enter a value for search rule"));
+			add_atk_relation (w, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
+			add_atk_relation (GTK_WIDGET(label), w, ATK_RELATION_LABEL_FOR);
+		}
+		g_signal_connect (G_OBJECT (w), "activate",
+				  G_CALLBACK (advanced_search_activate),
+				  find_buttons);
 		break;
 	default:
 		/* This should never happen, if it does, there is a bug */
@@ -1195,12 +1154,16 @@ create_option_box(FindOption *opt, gboolean enabled)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), enabled);
 	enable_option(w, opt);
 	gtk_box_pack_start(GTK_BOX(hbox), w, FALSE,FALSE,0);
+	if (gail_loaded)
+		add_atk_namedesc (GTK_WIDGET(w), NULL, _("Toggle On/Off to enable/disable the rule"));
 
 	w = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
 	gtk_widget_set_size_request (GTK_WIDGET(w), 88, -1);
 	g_signal_connect(G_OBJECT(w), "clicked",
 			 G_CALLBACK(remove_option), opt);
 	gtk_box_pack_start(GTK_BOX(hbox), w, FALSE,FALSE, 0);
+	if (gail_loaded)
+		add_atk_namedesc (GTK_WIDGET(w), NULL, _("Click to Remove the Rule"));
 
 	return hbox;
 }
@@ -1234,7 +1197,7 @@ create_find_page(void)
 {
 	GtkWidget *vbox, *vbox2;
 	GtkWidget *hbox, *hbox2;
-	GtkWidget *label, *w;
+	GtkWidget *label, *w, *gnome_entry;
 	GtkWidget *vpaned, *image, *align;
 	GtkWidget *frame, *frame2;
 	GtkTreeViewColumn *column;
@@ -1246,13 +1209,24 @@ create_find_page(void)
 
 	hbox = gtk_hbox_new(FALSE,GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
-	w = gtk_label_new_with_mnemonic(_("S_tarting in folder:"));
-	gtk_box_pack_start(GTK_BOX(hbox),w,FALSE,FALSE,0);
+	label = gtk_label_new_with_mnemonic(_("S_tarting in folder:"));
+	gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE,0);
 	start_dir_e = gnome_file_entry_new("directory", _("Browse"));
 	gnome_file_entry_set_directory_entry(GNOME_FILE_ENTRY(start_dir_e), TRUE);
 	gtk_box_pack_start(GTK_BOX(hbox),start_dir_e,TRUE,TRUE,GNOME_PAD_SMALL);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(w), gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(start_dir_e)));
-	w = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(start_dir_e));
+	w = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(start_dir_e));
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), w);
+	gnome_entry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(start_dir_e));
+	if (gail_loaded)
+	{ 
+		add_atk_namedesc (GTK_WIDGET(gnome_entry), _("Starting folder entry"), _("Enter the folder name where you want to start the search"));
+		add_atk_namedesc (GTK_WIDGET(w), _("Starting folder entry"), _("Enter the folder name where you want to start the search"));
+		add_atk_relation (gnome_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY); 
+	}
+	g_signal_connect (G_OBJECT (gnome_entry), "activate",
+			  G_CALLBACK (advanced_search_activate),
+			  find_buttons);
+
 	s = g_get_current_dir();
 	gtk_entry_set_text(GTK_ENTRY(w), s);
 	g_free(s);
@@ -1291,11 +1265,17 @@ create_find_page(void)
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_WIDGET(w));
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(w), make_list_of_templates());
 	gtk_box_pack_start(GTK_BOX(hbox),w,FALSE,FALSE,0);
+
+	if (gail_loaded)
+	{
+		add_atk_namedesc (GTK_WIDGET(w), _("Search Rules Menu"), _("Select a search rule from the menu"));
+		add_atk_relation (w, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
+	}
+
 	w = gtk_button_new_from_stock(GTK_STOCK_ADD);
 	gtk_widget_set_size_request (GTK_WIDGET(w), 88, -1);
 	g_signal_connect(G_OBJECT(w),"clicked",
 			 G_CALLBACK(add_option_cb),NULL);
-
 	add_option(0, TRUE);
 	gtk_box_pack_start(GTK_BOX(hbox),w,FALSE,FALSE,0);
 	
@@ -1328,8 +1308,14 @@ create_find_page(void)
 	gtk_box_pack_end(GTK_BOX(hbox),find_buttons[0],FALSE,FALSE,GNOME_PAD_SMALL);
 	gtk_box_pack_end(GTK_BOX(hbox),find_buttons[1],FALSE,FALSE,GNOME_PAD_SMALL);
 	gtk_widget_set_sensitive(find_buttons[0],FALSE);
-
-	
+ 
+	if (gail_loaded)
+	{
+		add_atk_namedesc (GTK_WIDGET(w), NULL, _("Click to Add a Rule"));
+		add_atk_namedesc (GTK_WIDGET(find_buttons[1]), NULL , _("Click to Start the Search"));
+		add_atk_namedesc (GTK_WIDGET(find_buttons[0]), NULL, _("Click to Stop the Search"));
+	}
+             
 	/* create search results section */
 	frame = gtk_frame_new(NULL);
 	gtk_paned_pack2 (GTK_PANED (vpaned), frame, TRUE, FALSE);
@@ -1491,10 +1477,37 @@ locate_activate (GtkWidget *entry, gpointer data)
 	run_locate_command (buttons[1], buttons);
 }
 
+/*
+ * This function stops the search when user presses Escape while the search
+ * is underway.
+ */
+
+static gboolean
+stop_search (GtkWidget *w, GdkEventKey *event)
+{
+	GtkWidget **buttons;
+	g_return_if_fail (GTK_IS_WIDGET(w));
+
+	if (event->keyval == GDK_Escape)
+	{
+		if (locate_running == RUNNING)
+		{
+			buttons = locate_buttons;
+			run_locate_command (buttons[0], buttons);
+		}
+		else if (find_running == RUNNING)
+		{
+			buttons = find_buttons;
+			run_command (buttons[0], buttons);
+		}
+	}
+	return FALSE;
+}
+
 static GtkWidget *
 create_locate_page(void)
 {
-	GtkWidget *w, *vbox, *hbox, *hbox2;
+	GtkWidget *w, *vbox, *hbox, *hbox2, *entry;
 	GtkWidget *image, *label, *frame, *align;
 	GtkTreeViewColumn *column;	
 	static gchar *history = NULL;
@@ -1512,7 +1525,16 @@ create_locate_page(void)
 	gtk_label_set_mnemonic_widget(GTK_LABEL(w), gnome_entry_gtk_entry(GNOME_ENTRY(locate_entry)));
 	gnome_entry_set_max_saved(GNOME_ENTRY(locate_entry), 10);
 	gtk_box_pack_start(GTK_BOX(hbox), locate_entry, TRUE, TRUE, 0);
-	
+	entry =  gnome_entry_gtk_entry (GNOME_ENTRY(locate_entry));
+       
+	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(locate_entry)))
+	{
+		gail_loaded = TRUE;
+		add_atk_namedesc (locate_entry, _("File Name Entry"), _("Enter the file name you want to search"));
+		add_atk_namedesc (entry, _("File Name Entry"), _("Enter the file name you want to search"));
+		add_atk_relation (locate_entry, GTK_WIDGET(w), ATK_RELATION_LABELLED_BY);
+	}	
+     
 	g_signal_connect (G_OBJECT (locate_entry), "activate",
 			  G_CALLBACK (locate_activate),
 			  locate_buttons);
@@ -1546,6 +1568,12 @@ create_locate_page(void)
 	gtk_box_pack_end(GTK_BOX(hbox),locate_buttons[0],FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),locate_buttons[1],FALSE,FALSE,0);
 	gtk_widget_set_sensitive(locate_buttons[0],FALSE);
+  
+	if (gail_loaded)
+	{
+		add_atk_namedesc (GTK_WIDGET(locate_buttons[1]), NULL, _("Click to Start the search"));
+		add_atk_namedesc (GTK_WIDGET(locate_buttons[0]), NULL, _("Click to Stop the search"));
+	}
 
 	/* create search results section */
 	frame = gtk_frame_new(NULL);
@@ -1661,10 +1689,9 @@ create_window(void)
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(nbook),create_locate_page(),
 				 gtk_label_new_with_mnemonic(_("Si_mple")));  /* Can we connect to this  */
-
 	gtk_notebook_append_page(GTK_NOTEBOOK(nbook),create_find_page(),
 				 gtk_label_new_with_mnemonic(_("Ad_vanced")));
-	
+
 	return nbook;
 }
 
@@ -1749,7 +1776,7 @@ save_results(GtkFileSelection *selector, gpointer user_data)
 				gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, COLUMN_NAME, &utf8_name, -1);
 				gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);	
 				
-				file = get_file_full_path_name (utf8_path, utf8_name);					    
+				file = g_build_filename (utf8_path, utf8_name, NULL);					    
 				fprintf(fp, "%s\n", file);
 				
 				g_free(utf8_path);
@@ -1872,7 +1899,9 @@ main(int argc, char *argv[])
 
 	g_signal_connect(G_OBJECT(app), "button_press_event",
 			 G_CALLBACK(window_click), NULL);
-		
+	g_signal_connect(G_OBJECT(app), "key_press_event",
+		         G_CALLBACK(stop_search), NULL);
+
 	/*set up session management*/		 
 	client = gnome_master_client ();		 
 			 
