@@ -79,14 +79,12 @@ int numlogs, curlognum;
 int log_line_sep;
 int cursor_visible;
 int canvas_width, canvas_height;
-char *deflognames[] =
-{PATH_MESSAGES};
-
 char *month[12] =
 {N_("January"), N_("February"), N_("March"), N_("April"), N_("May"),
  N_("June"), N_("July"), N_("August"), N_("September"), N_("October"),
  N_("November"), N_("December")};
 extern GtkWidget *main_win_scrollbar;
+extern 
 
 /*
  * -------------------
@@ -192,28 +190,47 @@ NumTextLines (int l)
 gboolean
 handle_log_mouse_button (GtkWidget * win, GdkEventButton *event)
 {
-  static guint32 lasttime;
-  static int clicked_before = FALSE;
 
-  if (event->type == GDK_BUTTON_PRESS && !clicked_before)
-    {
-      lasttime = event->time;
-      clicked_before = TRUE;
+  if (event->type == GDK_2BUTTON_PRESS) {
+    if (!zoom_visible)
+      create_zoom_view (NULL, NULL);
+  }
+  else if (event->button == 1) {
+    int cursory, nl;
+    Page *np;
+    if (curlog == NULL)
       return FALSE;
-    }
-  
-  clicked_before = FALSE;
-  if (event->time - lasttime < 100 ||
-      event->time - lasttime > 200)
-    return FALSE;
 
-  /* If zoom is already visible ignore */
-  if (!zoom_visible)
-    create_zoom_view (NULL, NULL);
+     cursory = event->y;
+     cursor_visible = TRUE;
+     if ((nl = GetLineAtCursor (cursory)) != -1 && nl != curlog->pointerln)
+     {
+       np = GetPageAtCursor (cursory);
+       log_redrawcursor (curlog->pointerln, nl, np);
+       curlog->pointerln = nl;
+       curlog->pointerpg = np;
+       log_redrawdetail ();
+     }
+  } 
 
   return FALSE;
 }
 
+gboolean
+handle_log_mouse_scroll (GtkWidget * win, GdkEventScroll *event)
+{
+  GtkAdjustment *adj;
+  adj = GTK_ADJUSTMENT (GTK_RANGE (main_win_scrollbar)->adjustment);
+
+  if (event->direction == GDK_SCROLL_UP)
+    gtk_adjustment_set_value (adj, (adj->value - 5.0));
+  else if (event->direction == GDK_SCROLL_DOWN)
+    gtk_adjustment_set_value (adj, (adj->value + 5.0));
+    
+  return FALSE;
+
+}
+
 /* ----------------------------------------------------------------------
    NAME:        HandleLogKeyboard
    DESCRIPTION: Handle all posible keyboard actions.
@@ -422,7 +439,10 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
 
    /* Check that there is at least one log */
    if (curlog == NULL)
+   {
+      UpdateStatusArea ();	   
       return FALSE;
+   }
 
    pg = curlog->currentpg;
    ln = curlog->firstline;
@@ -477,7 +497,11 @@ UpdateStatusArea ()
   const char *time_fmt = _("%x"); /* an evil way to avoid warning */
 
   if (curlog == NULL)
-    return;
+  {
+      gtk_label_set_text (filename_label, "");
+      gtk_label_set_text (date_label, "");    
+      return;
+  }
 
   if (curlog->name != NULL)
     {
@@ -761,7 +785,7 @@ InitPages ()
    numlogs = 0;
    for (i = 0; i < DEF_NUM_LOGS; i++)
      {
-       curlog = OpenLogFile (deflognames[i]);
+       curlog = OpenLogFile (user_prefs->logfile);
        if (curlog == NULL)
 	 continue;
        loglist[numlogs] = curlog;
