@@ -43,6 +43,7 @@ gboolean log_repaint (GtkWidget * canvas, GdkRectangle * area);
 gboolean PointerMoved (GtkWidget * canvas, GdkEventMotion * event);
 gboolean HandleLogKeyboard (GtkWidget * win, GdkEventKey * event_key);
 gboolean handle_log_mouse_button (GtkWidget * win, GdkEventButton *event);
+gboolean handle_log_mouse_scroll (GtkWidget * win, GdkEventScroll *event);
 void ExitProg (GtkWidget * widget, gpointer user_data);
 void LoadLogMenu (GtkWidget * widget, gpointer user_data);
 void CloseLogMenu (GtkWidget * widget, gpointer user_data);
@@ -115,9 +116,11 @@ GnomeUIInfo view_menu[] = {
         {GNOME_APP_UI_ITEM, N_("Zoom"), 
 	 N_("Show line info"), create_zoom_view, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 'Z', GDK_CONTROL_MASK, NULL},
-        {GNOME_APP_UI_ITEM, N_("Preferences..."), 
+       /* {GNOME_APP_UI_ITEM, N_("Preferences..."), 
 	 N_("Show user preferences"), UserPrefsDialog, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 'P', GDK_CONTROL_MASK, NULL},
+         GNOME_APP_PIXMAP_NONE, NULL, 'P', GDK_CONTROL_MASK, NULL},*/
+	/* As of now  user preference dialog does nothing except 
+        the hostname width adjustment in displaying */
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
@@ -160,6 +163,8 @@ GnomeUIInfo main_menu[] = {
 
 GtkWidget *app = NULL;
 GtkWidget *main_win_scrollbar = NULL;
+static GtkWidget *viewport;
+GtkWidget *main_win_hor_scrollbar = NULL; 
 GtkLabel *filename_label = NULL, *date_label = NULL;
 
 GList *regexp_db = NULL, *descript_db = NULL, *actions_db = NULL;
@@ -169,6 +174,18 @@ ConfigData *cfg = NULL;
 GtkWidget *open_file_dialog = NULL;
 
 GConfClient *client;
+poptContext poptCon;
+gint next_opt;
+
+struct poptOption options[] = { {
+	"file",
+	'f',
+	POPT_ARG_STRING,
+	NULL,
+	1,
+	NULL,
+	NULL,
+} };
 
 extern GdkGC *gc;
 extern Log *curlog, *loglist[];
@@ -187,6 +204,70 @@ destroy (void)
    CloseApp ();
 }
 
+static gint
+save_session (GnomeClient *gclient, gint phase,
+              GnomeRestartStyle save_style, gint shutdown,
+              GnomeInteractStyle interact_style, gint fast,
+              gpointer client_data)
+{
+   gchar **argv;
+   gint i;
+
+   argv = g_malloc0 (sizeof (gchar *) * (numlogs+1));
+   argv[0] = (gchar *) client_data;
+   for ( i = 1; i <= numlogs; i++) 
+       argv[i] = g_strconcat ("--file=", loglist[i-1]->name, NULL);
+   
+   gnome_client_set_clone_command (gclient, numlogs+1, argv);
+   gnome_client_set_restart_command (gclient, numlogs+1, argv);
+
+   g_free (argv);
+
+   return TRUE;
+}
+
+static gboolean
+restore_session (void)
+{
+   Log *tl;
+   gint i, logcnt = 0;
+
+   /* closing the log file opened by default */
+   CloseLog (loglist[0]);
+   curlog = NULL;
+   loglist[0] = NULL;
+   curlognum = 0;
+   log_repaint (NULL, NULL);
+   if (loginfovisible)
+       RepaintLogInfo (NULL, NULL);
+   set_scrollbar_size (1);
+   numlogs = 0;
+
+   next_opt = poptGetNextOpt (poptCon);
+
+   do {
+      if ( next_opt == 1) {
+         gchar *f = (gchar *) poptGetOptArg (poptCon);
+         if (f != NULL) {
+            if ((tl = OpenLogFile (f)) != NULL) {
+               curlog = tl;
+               loglist[numlogs] = tl;
+               numlogs++;
+               curlognum = numlogs - 1;
+            }
+         }
+         if (f)
+            g_free (f);
+      }
+   } while ((next_opt = poptGetNextOpt (poptCon)) != -1);
+}
+
+static gint
+die (GnomeClient *gclient, gpointer client_data)
+{
+    gtk_main_quit ();
+}
+
 /* ----------------------------------------------------------------------
    NAME:          main
    DESCRIPTION:   Program entry point.
@@ -195,6 +276,8 @@ destroy (void)
 int
 main (int argc, char *argv[])
 {
+  GnomeClient *gclient;
+
   bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
   textdomain(GETTEXT_PACKAGE);
@@ -202,10 +285,17 @@ main (int argc, char *argv[])
   QueueErrMessages (TRUE);
 
   /*  Initialize gnome & gtk */
-  gnome_init ("logview", VERSION, argc, argv);
+  gnome_init ("gnome-system-log", VERSION, argc, argv);
 
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-log.png");
   
+  poptCon = poptGetContext ("gnome-system-log", argc, (const gchar **) argv, 
+                            options, 0);  
+  gclient = gnome_master_client ();
+  g_signal_connect (gclient, "save_yourself",
+                    G_CALLBACK (save_session), (gpointer)argv[0]);
+  g_signal_connect (gclient, "die", G_CALLBACK (die), NULL);
+
   gconf_init (argc, argv, NULL);
   client = gconf_client_get_default ();
   
@@ -220,6 +310,10 @@ main (int argc, char *argv[])
   QueueErrMessages (FALSE);
   ShowQueuedErrMessages ();
    
+  if (gnome_client_get_flags (gclient) & GNOME_CLIENT_RESTORED) {
+     restore_session ();
+  }
+
   /*  Loop application */
   gtk_main ();
   
@@ -302,24 +396,28 @@ CreateMainWin ()
    table = gtk_table_new (2, 2, FALSE);
    gtk_widget_show (table);
 
-   w = gtk_viewport_new (NULL, NULL);
-   gtk_widget_set_usize (w, LOG_CANVAS_W, 0); 
-   gtk_widget_show (w);
+   viewport = gtk_viewport_new (NULL, NULL);
+   gtk_widget_set_usize (viewport, LOG_CANVAS_W, 0); 
+   gtk_widget_show (viewport);
                
    canvas = gtk_drawing_area_new ();
    /*gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, LOG_CANVAS_H); */
    gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W,
 			  LOG_CANVAS_H); 
    /*gtk_widget_set_usize ( GTK_WIDGET (canvas), LOG_CANVAS_W, LOG_CANVAS_H);*/
-   gtk_container_add (GTK_CONTAINER (w), canvas);
-   gtk_table_attach (GTK_TABLE (table), w, 0, 1, 0, 1,
+   gtk_container_add (GTK_CONTAINER (viewport), canvas);
+   gtk_table_attach (GTK_TABLE (table), viewport, 0, 1, 0, 1,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 
-   adj = (GtkObject *)gtk_viewport_get_hadjustment (GTK_VIEWPORT (w));
-   w = gtk_hscrollbar_new (GTK_ADJUSTMENT (adj));
-   gtk_widget_show (w);
-   gtk_table_attach (GTK_TABLE (table), w, 0, 1, 1, 2,
+   if (curlog != NULL)
+	   adj = (GtkObject *)gtk_viewport_get_hadjustment (GTK_VIEWPORT (viewport));
+   else
+	   adj = gtk_adjustment_new (100.0, 0.0, 101.0, 1, 10, 101.0);
+   
+   main_win_hor_scrollbar = gtk_hscrollbar_new (GTK_ADJUSTMENT (adj));
+   gtk_widget_show(main_win_hor_scrollbar);
+   gtk_table_attach (GTK_TABLE (table), main_win_hor_scrollbar, 0, 1, 1, 2,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		     (GtkAttachOptions) (0), 0, 0);
 
@@ -339,9 +437,6 @@ CreateMainWin ()
    gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
 		       (GtkSignalFunc) MainWinScrolled,
 		       (gpointer) main_win_scrollbar);       
-   gtk_signal_connect (GTK_OBJECT (main_win_scrollbar), "button_release_event", 
- 		       (GtkSignalFunc) ScrollWin, 
- 		       (gpointer) main_win_scrollbar);        
    gtk_widget_show (main_win_scrollbar);  
 
 
@@ -350,17 +445,23 @@ CreateMainWin ()
    /*  Install event handlers */
    gtk_signal_connect (GTK_OBJECT (canvas), "expose_event",
 		       GTK_SIGNAL_FUNC (log_repaint), NULL);
+#if 0
    gtk_signal_connect (GTK_OBJECT (canvas), "motion_notify_event",
 		       GTK_SIGNAL_FUNC (PointerMoved), NULL);
+#endif
    gtk_signal_connect (GTK_OBJECT (app), "key_press_event",
 		       GTK_SIGNAL_FUNC (HandleLogKeyboard), NULL);
-   gtk_signal_connect (GTK_OBJECT (app), "button_press_event",
+   gtk_signal_connect (GTK_OBJECT (canvas), "button_press_event",
 		       GTK_SIGNAL_FUNC (handle_log_mouse_button), NULL);
+   g_signal_connect (G_OBJECT (canvas), "scroll_event", 
+   		     G_CALLBACK (handle_log_mouse_scroll), NULL);
    gtk_signal_connect (GTK_OBJECT (canvas), "size_allocate",
 		       GTK_SIGNAL_FUNC (CanvasResized), NULL);
    gtk_widget_set_events (canvas, GDK_EXPOSURE_MASK |
 			  GDK_BUTTON_PRESS_MASK |
-			  GDK_POINTER_MOTION_MASK );
+			  GDK_POINTER_MOTION_MASK |
+			  GDK_SCROLL_MASK
+			  );
 
    gtk_widget_set_events (app, GDK_KEY_PRESS_MASK);
 
@@ -550,10 +651,22 @@ void set_scrollbar_size (int num_lines)
   gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
 		      (GtkSignalFunc) MainWinScrolled,
 		      (gpointer) main_win_scrollbar);       
-  gtk_adjustment_set_value (GTK_ADJUSTMENT(adj), curlog->ln);
+  if (curlog != NULL )
+  {
+  	gtk_adjustment_set_value (GTK_ADJUSTMENT(adj), curlog->ln); 
+	adj = (GtkObject*)gtk_viewport_get_hadjustment (GTK_VIEWPORT (viewport));
+  	gtk_adjustment_set_value (GTK_ADJUSTMENT(adj),0); 
+  }
+  else
+	adj = gtk_adjustment_new (100.0, 0.0, 101.0, 1, 10, 101.0);
+
+  gtk_range_set_adjustment (GTK_RANGE (main_win_hor_scrollbar),GTK_ADJUSTMENT (adj));
+
   gtk_widget_realize (main_win_scrollbar);
+  gtk_widget_realize (main_win_hor_scrollbar);
 
   gtk_widget_queue_resize (main_win_scrollbar);
+  gtk_widget_queue_resize (main_win_hor_scrollbar);
 }
 
 /* ----------------------------------------------------------------------
@@ -579,6 +692,11 @@ CloseLogMenu (GtkWidget * widget, gpointer user_data)
       log_repaint (NULL, NULL);
       if (loginfovisible)
 	 RepaintLogInfo (NULL, NULL);
+      set_scrollbar_size (1);
+      gtk_widget_set_sensitive (file_menu[2].widget, FALSE); 
+      gtk_widget_set_sensitive (file_menu[4].widget, FALSE); 
+      for ( i = 0; i < 4; i++) 
+         gtk_widget_set_sensitive (view_menu[i].widget, FALSE); 
       return;
    }
    for (i = curlognum; i < numlogs; i++)
@@ -651,8 +769,16 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
 	 /* Set main scrollbar */
 	 set_scrollbar_size (curlog->lstats.numlines);
 
-	 if (numlogs >= 2)
-	   gtk_widget_set_sensitive (file_menu[3].widget, TRUE);
+	 if (numlogs)
+	 {
+	   int i;
+	   if (numlogs >= 2)
+	     gtk_widget_set_sensitive (file_menu[3].widget, TRUE);
+	   gtk_widget_set_sensitive (file_menu[2].widget, TRUE);
+	   gtk_widget_set_sensitive (file_menu[4].widget, TRUE);
+	   for ( i = 0; i < 4; i++) 
+	     gtk_widget_set_sensitive (view_menu[i].widget, TRUE);
+	 } 
       }
    }
    g_free (f);
@@ -671,7 +797,10 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
 
    /*  Cannot open more than MAX_NUM_LOGS */
    if (numlogs == MAX_NUM_LOGS)
-      return;
+     { 
+       ShowErrMessage (_("Too many open logs. Close one and try again")); 
+       return;
+     }
    
    /*  Cannot have more than one fileselect window */
    /*  at one time. */
@@ -736,7 +865,9 @@ CloseApp (void)
 
    for (i = 0; i < numlogs; i++)
       CloseLog (loglist[i]);
-      
+
+   numlogs = 0;
+
    gtk_main_quit ();   
 }
 
@@ -870,9 +1001,9 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 	}
 	else {
 		/* First time running logview. Try to find the logfile */
-		if (lstat("/var/adm/messages", &filestat)) 
-			prefs->logfile = g_strdup ("/var/log/messages");
-		else if (lstat("/var/log/messages", &filestat)) 
+		if (lstat("/var/adm/messages", &filestat) == 0) 
+			prefs->logfile = g_strdup ("/var/adm/messages");
+		else if (lstat("/var/log/messages", &filestat) == 0) 
 			prefs->logfile = g_strdup ("/var/log/messages");
 		else
 			prefs->logfile = NULL;
