@@ -21,9 +21,17 @@ static gchar *file_icon = NULL;
 static gchar *folder_icon = NULL;
 static gchar *compress_icon = NULL;
 static gchar *tar_prog = NULL;
+static gchar *sh_prog = NULL;
+static gchar *gzip_prog = NULL;
+static gchar *tarstr = NULL;
+static gchar *filestr = NULL;
+static gchar *gzipstr = NULL;
 static gchar *filename = NULL;
 static pid_t temporary_pid = 0;
 static gchar *temporary_file = NULL;
+struct poptOption options;
+
+static GtkWidget *create_archive_widget=NULL;
 
 #define ERRDLG(error) gtk_message_dialog_new (GTK_WINDOW(app), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error);
 #define ERRDLGP(error,parent) gtk_message_dialog_new (GTK_WINDOW(parent), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error);
@@ -61,6 +69,17 @@ free_file (File *f)
 	g_free (f);
 }
 
+static void 
+cleanup_tmpstr (void)
+{
+	g_free(tarstr);
+	tarstr = NULL;
+	g_free(filestr);
+	filestr = NULL;
+	g_free(gzipstr);
+	gzipstr = NULL;
+}
+
 static char *
 make_temp_dir (void)
 {
@@ -139,6 +158,7 @@ remove_pos (gint pos)
 
 	if (number_of_files + number_of_dirs <= 0) {
 		gtk_widget_set_sensitive (compress_button, FALSE);
+		gtk_widget_set_sensitive (create_archive_widget, FALSE);
 	}
 
 	update_status ();
@@ -157,7 +177,7 @@ make_argv_fe (gpointer key, gpointer value, gpointer user_data)
 	struct argv_adder *argv_adder = user_data;
 	gchar *file = g_build_filename ((argv_adder->link_dir), (f->base_name), NULL);
 
-	argv_adder->argv[argv_adder->pos ++] = f->base_name;
+	argv_adder->argv[argv_adder->pos ++] = g_strconcat ("\"", f->base_name, "\"", NULL);
 
 	/* FIXME: catch errors */
 	symlink (f->name, file);
@@ -205,14 +225,21 @@ create_archive (const gchar *fname,
 	else
 		argv_adder.link_dir = (gchar *)dir;
 
-	argv_adder.argv = g_new (gchar *, number_of_files + number_of_dirs + 4);
-	argv_adder.argv[number_of_files + number_of_dirs + 3] = NULL;
-	argv_adder.argv[0] = tar_prog;
-	argv_adder.argv[1] = "-chzf";
-	argv_adder.argv[2] = (gchar *)fname;
-	argv_adder.pos = 3;
+        /* Since tar -z option is not available in Solaris, doing tar & gzip */
 
+	argv_adder.argv = g_new (gchar *, number_of_files + number_of_dirs + 4);
+	argv_adder.pos = 0;
 	g_hash_table_foreach (file_ht, make_argv_fe, &argv_adder);
+	argv_adder.argv[argv_adder.pos ++] = NULL;
+
+	tarstr = g_strconcat(tar_prog, " -chf - ", NULL);
+	filestr = g_strjoinv(" ", argv_adder.argv);
+	gzipstr = g_strconcat(" | ", gzip_prog, " - > ", (gchar *)fname, NULL);
+
+	argv_adder.argv[0] = sh_prog;
+	argv_adder.argv[1] = "-c";
+	argv_adder.argv[2] = g_strconcat(tarstr, filestr, gzipstr, NULL);	
+	argv_adder.argv[3] = NULL;
 
 	/* FIXME: get error output, check for errors, etc... */
 
@@ -229,8 +256,9 @@ create_archive (const gchar *fname,
 		umask (022);
 		/* FIXME: handler errors */
 		chdir (argv_adder.link_dir);
-		execv (tar_prog, argv_adder.argv);
+		execv (sh_prog, argv_adder.argv);
 		fprintf (stderr, _("Cannot run tar/gtar"));
+		cleanup_tmpstr ();
 		_exit (1);
 	}
 
@@ -248,7 +276,7 @@ create_archive (const gchar *fname,
 	}
 
 	g_free (argv_adder.argv);
-
+	cleanup_tmpstr ();
 	return status;
 }
 
@@ -431,6 +459,7 @@ clear_cb (GtkWidget *w, gpointer data)
 	number_of_files = number_of_dirs = 0;
 	gnome_icon_list_clear (GNOME_ICON_LIST (icon_list));
 	gtk_widget_set_sensitive (compress_button, FALSE);
+	gtk_widget_set_sensitive (create_archive_widget, FALSE);
 	update_status ();
 }
 
@@ -582,6 +611,7 @@ add_file (const gchar *file)
 	}
 
 	gtk_widget_set_sensitive (compress_button, TRUE);
+	gtk_widget_set_sensitive (create_archive_widget, TRUE);
 
 	f = g_new0 (File, 1);
 	f->type = type;
@@ -749,12 +779,12 @@ init_gui (void)
 
 	tips = gtk_tooltips_new ();
 
-        app = gnome_app_new ("meat-grinder",
+        app = gnome_app_new ("archive-generator",
 			     _("GNOME Archive Generator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app),
-				"meat-grinder",
-				"meat-grinder");
-	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
+				"archive-generator",
+				"archive-generator");
+	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 
         g_signal_connect (G_OBJECT (app), "delete_event",
 			  G_CALLBACK (quit_cb), NULL);
@@ -766,7 +796,7 @@ init_gui (void)
 	gtk_widget_show (vbox);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_set_usize (sw, 250, 150);
+	gtk_widget_set_size_request (sw, 250, 150);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
@@ -811,6 +841,7 @@ init_gui (void)
 			      NULL);
 
 	gtk_widget_set_sensitive (compress_button, FALSE);
+	gtk_widget_set_sensitive (file_menu[1].widget, FALSE);
 
 	/* setup dnd */
 	gtk_drag_source_set (compress_button,
@@ -854,20 +885,51 @@ got_signal (gint sig)
 	kill (getpid (), sig);
 }
 
+static gint
+save_session (GnomeClient *client, gint phase,
+ 	      GnomeRestartStyle save_style, gint shutdown,
+ 	      GnomeInteractStyle interact_style, gint fast,
+ 	      gpointer client_data)
+{
+ 	gchar *argv[] = { NULL };
+ 
+ 	argv[0] = (gchar *) client_data;
+ 	gnome_client_set_clone_command (client, 1, argv);
+ 	gnome_client_set_restart_command (client, 1, argv);
+ 
+ 	return TRUE;
+}
+ 
+static gint
+die (GnomeClient *client, gpointer client_data)
+{
+	gtk_main_quit ();
+}
+
 gint
 main (gint argc, gchar *argv [])
 {
 	gint i;
 	poptContext ctx;
 	const gchar **files;
+	GnomeClient *client;
 	
 	/* Initialize the i18n stuff */
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_init_with_popt_table ("meat-grinder", VERSION,
-				    argc, argv, NULL, 0, &ctx);
+	gnome_program_init ("archive-generator", VERSION, LIBGNOMEUI_MODULE,
+				    argc, argv, GNOME_PARAM_POPT_TABLE,
+				    &options, NULL);
+
+	client = gnome_master_client ();
+
+	g_signal_connect (client, "save_yourself",
+			  G_CALLBACK (save_session), (gpointer)argv[0]);
+
+	g_signal_connect (client, "die", G_CALLBACK (die), NULL);
+
 	/* no icon yet */
 	/*gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-meat-grinder.png");*/
 
@@ -910,11 +972,27 @@ main (gint argc, gchar *argv [])
 			  "This is the program used for creating archives."));
 		exit (1);
 	}
+	sh_prog = g_find_program_in_path ("sh");
+	if (sh_prog == NULL) {
+		g_print("Cannot find the shell (sh) program! Aborting");
+		exit (1);
+	}
+
+	gzip_prog = g_find_program_in_path ("gzip");
+	if (gzip_prog == NULL) {
+		g_print("Cannot find the compression (gzip) program!\n"
+			 "This is the program used for compressing archives.\n");
+		exit (1);
+	}
+
+	ctx = poptGetContext (PACKAGE, argc, (const char **) argv, &options, 0);
 
 	files = poptGetArgs (ctx);
 
 	init_gui ();
 
+	create_archive_widget = file_menu[1].widget;
+
 	file_ht = g_hash_table_new (g_str_hash, g_str_equal);
 
 	gnome_icon_list_freeze (GNOME_ICON_LIST (icon_list));
@@ -939,6 +1017,10 @@ main (gint argc, gchar *argv [])
 	gtk_main ();
 
 	cleanup_temporary ();
+
+	g_free(tar_prog);
+	g_free(sh_prog);
+	g_free(gzip_prog);
 	
 	return 0;
 }
